ClientActor

Struct ClientActor 

pub struct ClientActor(/* private fields */);

Implementations

Source

impl ClientActor

pub fn new(client: Client) -> Result<Self>

Source

impl ClientActor

pub async fn get_servers(&self) -> Result<Vec<(GUID, String)>>

Methods from Deref<Target = Addr<Client>>

pub fn connected(&self) -> bool

Returns whether the actor is still alive.

pub fn do_send<M>(&self, msg: M)
where M: Message + Send, <M as Message>::Result: Send, A: Handler<M>, <A as Actor>::Context: ToEnvelope<A, M>,

Sends a message unconditionally, ignoring any potential errors.

The message is always queued, even if the mailbox for the receiver is full. If the mailbox is closed, the message is silently dropped.

pub fn try_send<M>(&self, msg: M) -> Result<(), SendError<M>>
where M: Message + Send + 'static, <M as Message>::Result: Send, A: Handler<M>, <A as Actor>::Context: ToEnvelope<A, M>,

Tries to send a message.

This method fails if actor’s mailbox is full or closed. This method registers the current task in the receiver’s queue.

pub fn send<M>(&self, msg: M) -> MsgRequest<AddressSender<A>, M>
where M: Message + Send + 'static, <M as Message>::Result: Send, A: Handler<M>, <A as Actor>::Context: ToEnvelope<A, M>,

Sends an asynchronous message and waits for a response.

The communication channel to the actor is bounded. If the returned request future gets dropped, the message is cancelled.

pub fn downgrade(&self) -> WeakAddr<A>

Returns a downgraded WeakAddr.