RemotePointer

Struct RemotePointer 

pub struct RemotePointer<T: Sized> { /* private fields */ }
A safe wrapper around a pointer allocated by COM.

This struct ensures proper cleanup of COM-allocated memory when dropped. It provides methods to access the underlying pointer.

Implementations

Source

impl<T: Sized> RemotePointer<T>

pub fn null() -> Self

Creates a new RemotePointer initialized to null.

pub fn as_mut_ptr(&mut self) -> *mut *mut T

pub fn as_ref(&self) -> Option<&T>

Returns an Option referencing the inner value if it is not null.

Safety

The caller must ensure that the inner pointer is valid for reads.

pub fn ok(&self) -> Result<&T>

pub fn from_option<R: Into<RemotePointer<T>>>(value: Option<R>) -> Self

Source

impl RemotePointer<u16>

pub fn as_mut_pwstr_ptr(&mut self) -> *mut PWSTR

Returns a mutable pointer to a PWSTR.