pub struct ClientActor(/* private fields */);Implementations
Sourceimpl ClientActor
impl ClientActor
Methods from Deref<Target = Addr<Client>>
Sourcepub fn do_send<M>(&self, msg: M)
pub fn do_send<M>(&self, msg: M)
Sends a message unconditionally, ignoring any potential errors.
The message is always queued, even if the mailbox for the receiver is full. If the mailbox is closed, the message is silently dropped.
Sourcepub fn try_send<M>(&self, msg: M) -> Result<(), SendError<M>>
pub fn try_send<M>(&self, msg: M) -> Result<(), SendError<M>>
Tries to send a message.
This method fails if actor’s mailbox is full or closed. This method registers the current task in the receiver’s queue.
Sourcepub fn send<M>(&self, msg: M) -> MsgRequest<AddressSender<A>, M>
pub fn send<M>(&self, msg: M) -> MsgRequest<AddressSender<A>, M>
Sends an asynchronous message and waits for a response.
The communication channel to the actor is bounded. If the returned request future gets dropped, the message is cancelled.